SystemOrganization addCategory: #'GMF-UMLModel'!
SystemOrganization addCategory: 'GMF-UMLModel-Tests'!

TestCase subclass: #TestTransform
	instanceVariableNames: 'metamodel'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GMF-UMLModel-Tests'!

!TestTransform methodsFor: 'initialize-release' stamp: 'volosmat 4/24/2014 15:31'!
setUp
	TransformToUML clearTransformedElements.
	metamodel := MetaModel new! !

!TestTransform methodsFor: 'running' stamp: 'volosmat 4/24/2014 14:45'!
testAddTransformedElement

	UMLElement name: 'TestElement'.
	self assert: (TransformToUML searchTransformedElement: 'TestElement') name = 'TestElement'.! !

!TestTransform methodsFor: 'running' stamp: 'volosmat 4/24/2014 16:07'!
testCreateComposition
	| start end |
	start	:= UMLElement name: 'StartElement'.
	end		:= UMLElement name: 'EndElement'.
	
	UMLComposition 	nameStart: 			'start' 
						nameEnd: 			'end' 
						start: 				start
						startMultiplicity: 	'1' 
						end: 				end
						endMultiplicity: 		'1'.
								
	self assert: ( start compositions detect: [ :each | each start name = start name ] ) notNil.
	self assert: ( end compositions detect: [ :each | each end name = end name ] ) notNil.

		! !

!TestTransform methodsFor: 'running' stamp: 'volosmat 4/24/2014 15:34'!
testReplaceCapitalLetter
	self assert: ( Transform replaceCapitalLetter: 'TESt' ) = 'tESt'.
	self assert: ( Transform replaceCapitalLetter: 'test' ) = 'test'.
	
	self deny: ( Transform replaceCapitalLetter: 'TESt' ) = 'TESt'.
	self deny: ( Transform replaceCapitalLetter: 'test' ) = 'Test'.! !

!TestTransform methodsFor: 'running' stamp: 'volosmat 4/24/2014 16:03'!
testSearchComposition
	| start end |
	start	:= UMLElement name: 'StartElement'.
	end		:= UMLElement name: 'EndElement'.
	
	self deny: ( start searchComposition: 'start' end: 'end' ) notNil.
	self deny: ( end searchComposition: 'start' end: 'end' ) notNil.
	
	UMLComposition 	nameStart: 			'start' 
						nameEnd: 			'end' 
						start: 				start
						startMultiplicity: 	'1' 
						end: 				end
						endMultiplicity: 		'1'.
								
	self assert: ( start searchComposition: 'start' end: 'end' ) notNil.
	self assert: ( end searchComposition: 'start' end: 'end' ) notNil.

		! !

!TestTransform methodsFor: 'running' stamp: 'volosmat 4/24/2014 14:36'!
testSearchElementByName
	Kind name: 'TestElement' metaModel: metamodel.
	TransformToUML metaModel: metamodel.
	
	self assert: (TransformToUML searchElementByName: 'TestElement') name = 'TestElement'.
	self deny: (TransformToUML searchElementByName: 'testElement') notNil! !

!TestTransform methodsFor: 'running' stamp: 'volosmat 4/24/2014 14:46'!
testSearchTransformedElement
	Kind name: 'TestElement' metaModel: metamodel.
	
	TransformToUML metaModel: metamodel.
	self assert: (TransformToUML searchTransformedElement: 'TestElement') name = 'TestElement'.
	self deny: (TransformToUML searchTransformedElement: 'testElement') name = 'TestElement'.
	! !

TestCase subclass: #TestTransformAssociation
	instanceVariableNames: 'metamodel'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GMF-UMLModel-Tests'!

!TestTransformAssociation methodsFor: 'initialize-release' stamp: 'volosmat 4/24/2014 21:28'!
setUp
	TransformToUML clearTransformedElements.
	metamodel := MetaModel new! !

!TestTransformAssociation methodsFor: 'initialize-release' stamp: 'volosmat 4/24/2014 23:01'!
setUpCollective
	| collective |
	
	collective := Collective name: 'Friends' metaModel: metamodel.
	
	
	MemberOf 	name: 				'person' 
				start:				(Kind name: 'Person' metaModel: metamodel)
				startMultiplicity: 	'1'
				end: 				collective
				endMultiplicity: 		'1..*'.
						
	MemberOf 	name: 				'animal' 
				start:				(Kind name: 'Animal' metaModel: metamodel)
				startMultiplicity: 	'1'
				end: 				collective
				endMultiplicity: 		'1..*'.
						
	MemberOf 	name: 				'gadget' 
				start:				(Kind name: 'Gadget' metaModel: metamodel)
				startMultiplicity: 	'1'
				end: 				collective
				endMultiplicity: 		'1..*'.				
	! !

!TestTransformAssociation methodsFor: 'initialize-release' stamp: 'volosmat 4/24/2014 22:56'!
setUpEssential
	| brain person component heart |
	person 	:= Kind name: 'Person' metaModel: metamodel.
	brain    	:= Kind name: 'Brain' metaModel: metamodel.
	heart    := Kind name: 'Heart' metaModel: metamodel.
	
	component := ComponentOf 	name: 				'brain' 
									start:				brain
									startMultiplicity: 	'1'
									end: 				person
									endMultiplicity: 		'1'.
	component essential: true.
	
	component := ComponentOf 	name: 				'heart' 
									start:				heart
									startMultiplicity: 	'1'
									end: 				person
									endMultiplicity: 		'1'.
	component essential: true.! !

!TestTransformAssociation methodsFor: 'initialize-release' stamp: 'volosmat 4/24/2014 23:10'!
setUpInseparable
	| brain person component |
	person 	:= Kind name: 'Person' metaModel: metamodel.
	brain    	:= Kind name: 'Brain' metaModel: metamodel.
	
	component := ComponentOf 	name: 				'brain' 
									start:				brain
									startMultiplicity: 	'1'
									end: 				person
									endMultiplicity: 		'1'.
	component inseparable: true
	! !

!TestTransformAssociation methodsFor: 'initialize-release' stamp: 'volosmat 4/24/2014 22:53'!
setUpQuantity
	| bottle mineralWater minerals quantity |
	
	bottle			:= Kind name: 'Bottle' metaModel: metamodel.
	mineralWater 	:= Quantity name: 'MineralWater' metaModel: metamodel.
	minerals 		:= Quantity name: 'Minerals' metaModel: metamodel.
	
	FormalAssociation 	name: 				'containment'
						start: 				bottle
						startMultiplicity: 	'1'
						end: 				mineralWater
						endMultiplicity: 		'1'.
	
	quantity := SubQuantityOf 	name: 				'quantity' 
								start: 				minerals 
								startMultiplicity: 	'1' 
								end: 				mineralWater 
								endMultiplicity: 		'1'.
	quantity essential: true.! !

!TestTransformAssociation methodsFor: 'initialize-release' stamp: 'volosmat 4/24/2014 21:40'!
setUpRelator
	| relator husband wife person man woman material1 material2 |
	
	relator 		:= Relator name: 'Wedding' metaModel: metamodel.
	person 		:= Kind name: 'Person' metaModel: metamodel.
	wife 		:= Role name: 'Wife' metaModel: metamodel.
	woman 		:= SubKind name: 'Woman' metaModel: metamodel.
	man 		:= SubKind name: 'Man' metaModel: metamodel.
	husband 	:= Role name: 'Husband' metaModel: metamodel.
		
	ParentClass parentClass: person child: woman.
	ParentClass parentClass: person child: man.
	ParentClass parentClass: woman child: wife.
	ParentClass parentClass: man child: husband.
	
	material1 := MaterialAssociation 	name: 				'husbandOf' 
										start: 				husband  
										startMultiplicity: 	'1..*'  
										end: 				wife 
										endMultiplicity: 		'1..*'.
	material2 := MaterialAssociation 	name: 				'marriedTo' 
										start: 				wife  
										startMultiplicity: 	'1..*'  
										end: 				husband 
										endMultiplicity: 		'1..*'.
												
	Derivation 				name: 				'husbandOf' 
							start: 				relator  
							startMultiplicity: 	'1'  
							end: 				material1 
							endMultiplicity: 		'1'.
	Derivation 				name: 				'marriedTo' 
							start: 				relator  
							startMultiplicity: 	'1'  
							end: 				material2 
							endMultiplicity: 		'1'.
	Mediation			 	name: 				'husband' 
							start: 				husband  
							startMultiplicity: 	'1..*'  
							end: 				relator 
							endMultiplicity: 		'1'.
	Mediation			 	name: 				'wife' 
							start: 				wife  
							startMultiplicity: 	'1..*'  
							end: 				relator 
							endMultiplicity: 		'1'.! !

!TestTransformAssociation methodsFor: 'running' stamp: 'volosmat 4/24/2014 22:48'!
testTransformAssociation
	| element |
	self setUpRelator.
	TransformToUML metaModel: metamodel.
	"this test is very similar to testTransformDerivation only with one change"
	element := TransformToUML searchTransformedElement: 'Wedding'.
	self assert: (element compositions at: 1) nameStart 	= 'wedding'.
	self assert: (element compositions at: 1) nameEnd 	= 'wife'.
	self assert: (element compositions at: 2) nameStart 	= 'wedding'.
	self assert: (element compositions at: 2) nameEnd 	= 'husband'.! !

!TestTransformAssociation methodsFor: 'running' stamp: 'volosmat 4/24/2014 21:49'!
testTransformDerivation
	| element |
	self setUpRelator.
	TransformToUML metaModel: metamodel.
	
	element := TransformToUML searchTransformedElement: 'Wedding'.
	self assert: element compositions size 				= 2.
	self assert: (element compositions at: 1) nameStart 	= 'wedding'.
	self assert: (element compositions at: 1) nameEnd 	= 'wife'.
	self assert: (element compositions at: 2) nameStart 	= 'wedding'.
	self assert: (element compositions at: 2) nameEnd 	= 'husband'.! !

!TestTransformAssociation methodsFor: 'running' stamp: 'volosmat 4/24/2014 23:18'!
testTransformEssentialMeronymic
	| element |
	self setUpEssential.
	TransformToUML metaModel: metamodel.
	
	element := TransformToUML searchTransformedElement: 'Person'.
	self assert: element compositions size 						= 2.
	self assert: (element compositions at: 1) nameStart 			= 'person'.
	self assert: (element compositions at: 1) nameEnd				= 'heart'.
	self assert: (element compositions at: 2) nameStart 			= 'person'.
	self assert: (element compositions at: 2) nameEnd				= 'brain'.
	self assert: element methods size								= 1.
	self assert: (element methods atRandom) isConstructor.
	self assert: (element methods atRandom) name				= 'heart'.
	self assert: (element methods atRandom) parameters size		= 2.
	self assert: ((element methods atRandom) parameters at:2) 	= 'brain'.
	self assert: element defaultConstructor						= false.
					
	element := TransformToUML searchTransformedElement: 'Brain'.
	self assert: element compositions size 				= 1.
	self assert: (element compositions at: 1) nameStart 	= 'person'.
	self assert: (element compositions at: 1) nameEnd		= 'brain'.
	
	element := TransformToUML searchTransformedElement: 'Heart'.
	self assert: element compositions size 				= 1.
	self assert: (element compositions at: 1) nameStart 	= 'person'.
	self assert: (element compositions at: 1) nameEnd		= 'heart'.
! !

!TestTransformAssociation methodsFor: 'running' stamp: 'volosmat 4/24/2014 22:55'!
testTransformFormalAssociation
	| element |
	self setUpQuantity.
	TransformToUML metaModel: metamodel.
	
	element := TransformToUML searchTransformedElement: 'Bottle'.
	self assert: element compositions size 				= 1.
	self assert: (element compositions at: 1) nameStart 	= 'containment'.
	self assert: (element compositions at: 1) nameEnd		= 'containment'! !

!TestTransformAssociation methodsFor: 'running' stamp: 'volosmat 4/24/2014 23:28'!
testTransformInseparableMeronymic
	| element |
	self setUpInseparable.
	TransformToUML metaModel: metamodel.
	
	element := TransformToUML searchTransformedElement: 'Person'.
	self assert: element compositions size 				= 1.
	self assert: (element compositions at: 1) nameStart 	= 'person'.
	self assert: (element compositions at: 1) nameEnd		= 'brain'.
	
	element := TransformToUML searchTransformedElement: 'Brain'.
	self assert: element compositions size 				= 1.
	self assert: (element compositions at: 1) nameStart 	= 'person'.
	self assert: (element compositions at: 1) nameEnd		= 'brain'.
	self assert: element methods size						= 1.
	self assert: (element methods atRandom) isConstructor.
	self assert: (element methods atRandom) name		= 'person'.
	self assert: element defaultConstructor				= false.
	self assert: (element attributes atRandom) name 		= 'composited'! !

!TestTransformAssociation methodsFor: 'running' stamp: 'volosmat 4/24/2014 21:59'!
testTransformMaterialAssociation
	| element |
	self setUpRelator.
	TransformToUML metaModel: metamodel.
	
	element := TransformToUML searchTransformedElement: 'Wife'.
	self assert: element compositions size 				= 2.
	self assert: (element compositions at: 1) nameStart 	= 'roles'.
	self assert: (element compositions at: 1) nameEnd 	= 'woman'.
	self assert: (element compositions at: 2) nameStart 	= 'wedding'.
	self assert: (element compositions at: 2) nameEnd 	= 'wife'.
	
	element := TransformToUML searchTransformedElement: 'Husband'.
	self assert: element compositions size 				= 2.
	self assert: (element compositions at: 1) nameStart 	= 'roles'.
	self assert: (element compositions at: 1) nameEnd 	= 'man'.
	self assert: (element compositions at: 2) nameStart 	= 'wedding'.
	self assert: (element compositions at: 2) nameEnd 	= 'husband'.
! !

!TestTransformAssociation methodsFor: 'running' stamp: 'volosmat 4/24/2014 23:10'!
testTransformMemberOf
	| element |
	self setUpCollective.
	TransformToUML metaModel: metamodel.
	
	element := TransformToUML searchTransformedElement: 'Friends'.
	self assert: element compositions size = 3.
	self assert: ( element compositions allSatisfy: [ :each | (each nameStart = 'friends') & each nameEnd = 'members' ]).
	
	element := TransformToUML searchTransformedElement: 'Person'.
	self assert: element compositions size 				= 1.
	self assert: (element compositions at: 1) nameStart 	= 'friends'.
	self assert: (element compositions at: 1) nameEnd		= 'members'.
	
	element := TransformToUML searchTransformedElement: 'Animal'.
	self assert: element compositions size 				= 1.
	self assert: (element compositions at: 1) nameStart 	= 'friends'.
	self assert: (element compositions at: 1) nameEnd		= 'members'.
	
	element := TransformToUML searchTransformedElement: 'Gadget'.
	self assert: element compositions size 				= 1.
	self assert: (element compositions at: 1) nameStart 	= 'friends'.
	self assert: (element compositions at: 1) nameEnd		= 'members'.
			
	! !

!TestTransformAssociation methodsFor: 'running' stamp: 'volosmat 4/24/2014 22:54'!
testTransformSubQuantityOf
	| element |
	self setUpQuantity.
	TransformToUML metaModel: metamodel.
	
	element := TransformToUML searchTransformedElement: 'MineralWater'.
	self assert: element compositions size 				= 2.
	self assert: (element compositions at: 2) nameStart 	= 'mineralWater'.
	self assert: (element compositions at: 2) nameEnd		= 'minerals'.
	self assert: (element compositions at: 1) nameStart 	= 'containment'.
	self assert: (element compositions at: 1) nameEnd		= 'containment'! !

TestCase subclass: #TestTransformClass
	instanceVariableNames: 'metamodel'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GMF-UMLModel-Tests'!

!TestTransformClass methodsFor: 'initialize-release' stamp: 'volosmat 4/24/2014 15:35'!
setUp
	TransformToUML clearTransformedElements.
	metamodel := MetaModel new! !

!TestTransformClass methodsFor: 'initialize-release' stamp: 'volosmat 4/24/2014 16:33'!
setUpElementWithAttribute
	| kind |
	
	kind :=  Kind 	name: 			'ElementWithAttribute' 
					abstract: 		false 
					metaModel: 	metamodel.
												
	Attribute 	name: 		'TestAttribute' 
				dataType: 	'string' 
				multiplicity: '1..*'
				element: 	kind.! !

!TestTransformClass methodsFor: 'initialize-release' stamp: 'volosmat 4/24/2014 17:04'!
setUpElementWithMethod
	| kind |
	
	kind :=  Kind 	name: 			'ElementWithMethod' 
					abstract: 		false 
					metaModel: 	metamodel.
												
	Method	name: 			'TestMethod' 
			instance: 		true
			constructor: 	false 
			element: 		kind.! !

!TestTransformClass methodsFor: 'initialize-release' stamp: 'volosmat 4/24/2014 16:17'!
setUpElementWithParent
	| kind subkind |
	
	kind :=  	Kind 		name: 			'Parent' 
							abstract: 		false 
							metaModel: 	metamodel.
												
	subkind :=  SubKind 	name: 			'Child' 
							abstract: 		false 
							metaModel: 	metamodel.
												
	ParentClass parentClass: 	kind
				 child:			subkind.
				! !

!TestTransformClass methodsFor: 'initialize-release' stamp: 'volosmat 4/24/2014 15:55'!
setUpElementWithoutParent
	Kind 	name: 			'KindWithoutParent' 
			abstract: 		true 
			metaModel: 	metamodel.! !

!TestTransformClass methodsFor: 'initialize-release' stamp: 'volosmat 4/24/2014 20:16'!
setUpMixinClass
	| category category2 item item2 parent |
	
	category := Category name: 'TestCategory1' metaModel: metamodel.
	
	category addSubObject: ( Kind name: 'TestSubObject1' metaModel: metamodel ).
	category addSubObject: ( item := SubKind name: 'TestSubObject2' metaModel: metamodel).
	
	parent := Kind name: 'TestKind' metaModel: metamodel.
	ParentClass parentClass: parent child: item.
	
	category2 := Category name: 'TestCategory2' metaModel: metamodel.
	category2 addSubObject: ( item2 := SubKind name: 'TestSubObject3' metaModel: metamodel ).
	category2 addSubObject: item.
	ParentClass parentClass: parent child: item2.! !

!TestTransformClass methodsFor: 'initialize-release' stamp: 'volosmat 4/24/2014 20:25'!
setUpNonDisjointInheritance
	| dog dachshund beagle |
	
	dog 		:= Kind name: 'Dog' metaModel: metamodel.
	dachshund 	:= SubKind name: 'Dachshund' metaModel: metamodel.
	beagle		:= SubKind name: 'Beagle' metaModel: metamodel.
	
	ParentClass 	parentClass: 	dog 
					complete: 		false 
					disjoint: 		false 
					child: 			dachshund.
								
	ParentClass 	parentClass: 	dog 
					complete: 		false 
					disjoint: 		false 
					child: 			beagle. 
	
	Attribute 	name: 'name' 
				dataType: 'string' 
				multiplicity: '1' 
				element: dog.
				
	Method name: 'doSomethingSpecial' 
			element: beagle.
			
	Method name: 'trackAnimal' 
			element: dachshund.! !

!TestTransformClass methodsFor: 'initialize-release' stamp: 'volosmat 4/24/2014 21:06'!
setUpPhase
	| being living dead |
	
	being  	:= Kind name: 'Being' metaModel: metamodel.
	living 	:= Phase name: 'Living' metaModel: metamodel.
	dead	:= Phase name: 'Dead' metaModel: metamodel.
	
	ParentClass 	parentClass: 	being 
					child: 			dead.
								
	ParentClass 	parentClass: 	being 
					child: 			living. ! !

!TestTransformClass methodsFor: 'initialize-release' stamp: 'volosmat 4/24/2014 18:48'!
setUpQuality
	| quality |
	quality := Quality name: 'Speed' metaModel: metamodel.
	quality asAttribute: true.
	
	Characterization 	name: 				'maxSpeed' 
						start: 				quality 
						startMultiplicity: 	'1' 
						end: 				(Kind name: 'Car' metaModel: metamodel) 
						endMultiplicity: 		'0..*'.
	
	Characterization 	name: 				'maxSpeedInSpace' 
						start: 				quality 
						startMultiplicity: 	'1' 
						end: 				(Kind name: 'SpaceShip' metaModel: metamodel) 
						endMultiplicity: 		'0..*'.
								! !

!TestTransformClass methodsFor: 'initialize-release' stamp: 'volosmat 4/24/2014 21:11'!
setUpRole
	| person man woman child |
	
	person	:= Kind name: 'Person' metaModel: metamodel.
	man	:= Role name: 'Man' metaModel: metamodel.
	woman	:= Role name: 'Woman' metaModel: metamodel.
	child	:= Role name: 'Child' metaModel: metamodel.
	
	ParentClass 	parentClass: 	person 
					complete: 		false 
					disjoint: 		true 
					child: 			man.
								
	ParentClass 	parentClass: 	person 
					complete: 		false 
					disjoint: 		true 
					child: 			woman. 
	
	ParentClass 	parentClass: 	person 
					complete: 		false 
					disjoint: 		false 
					child: 			child. ! !

!TestTransformClass methodsFor: 'running' stamp: 'volosmat 4/24/2014 16:57'!
testTransformElementWithAttribute
	| element |
	self setUpElementWithAttribute.
	TransformToUML metaModel: metamodel.
	
	element := TransformToUML searchTransformedElement: 'ElementWithAttribute'.
	
	self assert: element name 					= 'ElementWithAttribute'.
	self assert: element attributes size 		= 1.
	self assert: element methods size 			= 0.
	self assert: element compositions size 	= 0.
	self assert: element defaultConstructor.
	self assert: element isAbstract 			= false.
	self assert: element isComplete isNil.
	self assert: element isDisjoint isNil.
	self assert: element parent isNil.
	
	"We can use Set>>AtRandom because we have only 1 item in Set collection"
	self assert: (element attributes atRandom ) name 		= 'TestAttribute'.
	self assert: (element attributes atRandom ) dataType 	= 'string'.
	self assert: (element attributes atRandom) multiplicity 	= '1..*'.
! !

!TestTransformClass methodsFor: 'running' stamp: 'volosmat 4/24/2014 17:05'!
testTransformElementWithMethod
	| element |
	self setUpElementWithMethod.
	TransformToUML metaModel: metamodel.
	
	element := TransformToUML searchTransformedElement: 'ElementWithMethod'.
	
	self assert: element name 					= 'ElementWithMethod'.
	self assert: element attributes size 		= 0.
	self assert: element methods size 			= 1.
	self assert: element compositions size 	= 0.
	self assert: element defaultConstructor.
	self assert: element isAbstract 			= false.
	self assert: element isComplete isNil.
	self assert: element isDisjoint isNil.
	self assert: element parent isNil.
	
	"We can use Set>>atRandom because we have only 1 item in Set collection"
	self assert: (element methods atRandom ) name 			= 'TestMethod'.
	self assert: (element methods atRandom ) isConstructor 	= false.
	self assert: (element methods atRandom) isInstance.
! !

!TestTransformClass methodsFor: 'running' stamp: 'volosmat 4/24/2014 16:22'!
testTransformElementWithParent
	| element |
	self setUpElementWithParent.
	TransformToUML metaModel: metamodel.
	
	element := TransformToUML searchTransformedElement: 'Child'.
	
	self assert: element name 					= 'Child'.
	self assert: element attributes size 		= 0.
	self assert: element methods size 			= 0.
	self assert: element compositions size 	= 0.
	self assert: element defaultConstructor.
	self assert: element isAbstract 			= false.
	self assert: element isComplete.
	self assert: element isDisjoint.
	self assert: element parent name 			= 'Parent'.! !

!TestTransformClass methodsFor: 'running' stamp: 'volosmat 4/24/2014 16:23'!
testTransformElementWithoutParent
	| element |
	self setUpElementWithoutParent.
	TransformToUML metaModel: metamodel.
	
	element := TransformToUML searchTransformedElement: 'KindWithoutParent'.
	
	self assert: element name 					= 'KindWithoutParent'.
	self assert: element attributes size 		= 0.
	self assert: element methods size 			= 0.
	self assert: element compositions size 	= 0.
	self assert: element defaultConstructor.
	self assert: element isAbstract.
	self assert: element isComplete isNil.
	self assert: element isDisjoint isNil.
	self assert: element parent isNil.! !

!TestTransformClass methodsFor: 'running' stamp: 'volosmat 4/24/2014 20:16'!
testTransformMixinClass
	| element |
	self setUpMixinClass.
	TransformToUML metaModel: metamodel.
	
	element := TransformToUML searchTransformedElement: 'TestCategory1'.
	self assert: element name 					= 'TestCategory1'.
	self assert: element attributes size 		= 0.
	self assert: element compositions size 	= 2.

	element := TransformToUML searchTransformedElement: 'TestCategory2'.	
	self assert: element name 					= 'TestCategory2'.
	self assert: element attributes size 		= 0.
	self assert: element compositions size 	= 2.

	
	element := TransformToUML searchTransformedElement: 'TestSubObject1'.	
	self assert: element name 					= 'TestSubObject1'.
	self assert: element attributes size 		= 0.
	self assert: element compositions size 	= 1.
	self assert: element isComplete isNil.
	self assert: element isDisjoint isNil.
	self assert: element parent isNil.
	
	element := TransformToUML searchTransformedElement: 'TestSubObject2'.
	self assert: element name 					= 'TestSubObject2'.
	self assert: element attributes size 		= 0.
	self assert: element compositions size 	= 2.
	self assert: element isComplete.
	self assert: element isDisjoint.
	self assert: element parent name			= 'TestKind'.
				
	element := TransformToUML searchTransformedElement: 'TestSubObject3'.
	self assert: element name 					= 'TestSubObject3'.
	self assert: element attributes size 		= 0.
	self assert: element compositions size 	= 1.
	self assert: element isComplete.
	self assert: element isDisjoint.
	self assert: element parent name			= 'TestKind'.! !

!TestTransformClass methodsFor: 'running' stamp: 'volosmat 4/24/2014 20:35'!
testTransformNonDisjointInheritance
	| element |
	self setUpNonDisjointInheritance.
	TransformToUML metaModel: metamodel.
	
	element := TransformToUML searchTransformedElement: 'Dog'.
	self assert: element name 					= 'Dog'.
	self assert: element attributes size 		= 1.
	self assert: element compositions size 	= 0.
		
	element := TransformToUML searchTransformedElement: 'Beagle'.
	self assert: element name 					= 'Beagle'.
	self assert: element methods size 	    		= 1.
	self assert: element compositions size 	= 1.
	self assert: (element compositions at: 1) nameStart 	= 'beagle'.
	self assert: (element compositions at: 1) nameEnd 	= 'dachshundBeagle'.
	
	element := TransformToUML searchTransformedElement: 'Dachshund'.
	self assert: element name 					= 'Dachshund'.
	self assert: element methods size 	    		= 1.
	self assert: element compositions size 	= 1.
	self assert: (element compositions at: 1) nameStart 	= 'dachshund'.
	self assert: (element compositions at: 1) nameEnd 	= 'dachshundBeagle'.
		
	element := TransformToUML searchTransformedElement: 'DachshundBeagle'.
	self assert: element name 					= 'DachshundBeagle'.
	self assert: element methods size 	    		= 0.
	self assert: element compositions size 	= 2.
	self assert: (element compositions at: 1) nameStart 	= 'dachshund'.
	self assert: (element compositions at: 1) nameEnd 	= 'dachshundBeagle'.
	self assert: (element compositions at: 2) nameStart 	= 'beagle'.
	self assert: (element compositions at: 2) nameEnd 	= 'dachshundBeagle'.! !

!TestTransformClass methodsFor: 'running' stamp: 'volosmat 4/24/2014 21:07'!
testTransformPhase
	| element |
	self setUpPhase.
	TransformToUML metaModel: metamodel.
	
	element := TransformToUML searchTransformedElement: 'Being'.
	element compositions size 		= 1.
	(element compositions at:1) name 	= 'phase'.
	
	element := TransformToUML searchTransformedElement: 'Living'.
	element compositions size 		= 1.
	(element compositions at:1) name 	= 'being'.
	
	element := TransformToUML searchTransformedElement: 'Dead'.
	element compositions size 		= 1.
	(element compositions at:1) name 	= 'being'.! !

!TestTransformClass methodsFor: 'running' stamp: 'volosmat 4/24/2014 18:48'!
testTransformQuality
	| element |
	self setUpQuality.
	TransformToUML metaModel: metamodel.
	
	self assert: ( TransformToUML searchTransformedElement: 'Speed' ) isNil.
	
	element := TransformToUML searchTransformedElement: 'Car'.
	self assert: element name 					= 'Car'.
	self assert: element attributes size 		= 1.
	self assert: element methods size 			= 0.
	self assert: element compositions size 	= 0.
	
	element := TransformToUML searchTransformedElement: 'SpaceShip'.
	self assert: element name 					= 'SpaceShip'.
	self assert: element attributes size 		= 1.
	self assert: element methods size 			= 0.
	self assert: element compositions size 	= 0.
! !

!TestTransformClass methodsFor: 'running' stamp: 'volosmat 4/24/2014 21:08'!
testTransformRole
	| element |
	self setUpRole.
	TransformToUML metaModel: metamodel.
	
	element := TransformToUML searchTransformedElement: 'Person'.
	element compositions size 		= 1.
	(element compositions at:1) name 	= 'roles'.
	
	element := TransformToUML searchTransformedElement: 'Man'.
	element compositions size 		= 1.
	(element compositions at:1) name 	= 'person'.
	
	element := TransformToUML searchTransformedElement: 'Woman'.
	element compositions size 		= 1.
	(element compositions at:1) name 	= 'person'.
	
	element := TransformToUML searchTransformedElement: 'Child'.
	element compositions size 		= 1.
	(element compositions at:1) name 	= 'person'.! !

Object subclass: #DataForGenerator
	instanceVariableNames: 'UMLModel dataForGenerator'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GMF-UMLModel'!

DataForGenerator class
	instanceVariableNames: 'UMLElements dataForGenerator'!

!DataForGenerator commentStamp: 'volosmat 4/29/2014 10:22' prior: 0!
A DataForGenerator which is use for compatibility of data sent to GMF-Generator.

Example: 

CodeGenerator setDataWithAll: (DataForGenerator UMLElements: TransformToUML transformedElements).

For more examples see package GMF-Generator-Tests!

DataForGenerator class
	instanceVariableNames: 'UMLElements dataForGenerator'!

!DataForGenerator class methodsFor: 'initialize data' stamp: 'volosmat 4/24/2014 10:48'!
UMLElements: xUMLElements

	UMLElements 		:= xUMLElements.
	dataForGenerator	:= GeneratedAll new.
	^ self createAll! !

!DataForGenerator class methodsFor: 'private' stamp: 'volosmat 4/24/2014 11:28'!
createAll
	| class |
	"go over all uml elements"
	UMLElements 
		do: [:element | 
			"create new class"
			class := self createClass: element.
			"add attributes to class"
			element attributes
				do: [:attribute | 
					class addVariable: (self createAttribute: attribute) ]. 
			"add methods to class"	
			element methods
				do: [:method | 
					class addMethod: (self createMethod: method) ].
			"add parent of class"
			element parent notNil
				ifTrue: [class parent: (self searchClass: element parent name) ].
			"add new class to collection"
			dataForGenerator addClass: class].
	"create associations"
	UMLElements
		do: [:element | element compositions
				do: [:composition | composition start name = element name
						ifTrue: [self createAssociation: composition]]].
				
	 ^ dataForGenerator ! !

!DataForGenerator class methodsFor: 'private' stamp: 'volosmat 4/24/2014 11:22'!
createAssociation: xComposition
	| leftClass rightClass leftAttribute rightAttribute |
	
	"search left and right class of composition"
	leftClass 	:= self searchClass: xComposition start name.
	rightClass 	:= self searchClass: xComposition end name.
	"create attributes for composition"
	leftAttribute 	:= self createAttribute: ( Attribute 	name: 		xComposition nameStart 
														multiplicity: xComposition startMultiplicity ).
	rightAttribute 	:= self createAttribute: ( Attribute 	name: 		xComposition nameEnd
														multiplicity: xComposition endMultiplicity ).
	"add attributes to classes"		
	leftClass 	addVariable: leftAttribute.
	rightClass 	addVariable: rightAttribute.
	"create new association"
	GeneratedAssociation	newLeft: 		leftClass
							Var: 			leftAttribute 
							RIght: 			rightClass
							Var: 			rightAttribute
							essential: 		xComposition isEssential
							inseparable: 	xComposition isInseparable.! !

!DataForGenerator class methodsFor: 'private' stamp: 'volosmat 4/24/2014 11:24'!
createAttribute: xAttribute
	| attribute size |
	attribute := GeneratedEOCVariable 	newName: 	xAttribute name 
											Instance: 	xAttribute isInstance.
	size := xAttribute multiplicity size.	
										
	(size > 1) | (xAttribute multiplicity > '1')
		ifTrue: [attribute collection: 'OrderedCollection']. 
		
	^ attribute! !

!DataForGenerator class methodsFor: 'private' stamp: 'volosmat 4/24/2014 10:19'!
createClass: xElement
	^ GeneratedClass 	newName: 				xElement name
						defaultConstructor: 	xElement defaultConstructor.! !

!DataForGenerator class methodsFor: 'private' stamp: 'volosmat 4/24/2014 10:38'!
createMethod: xMethod
	| method |
	
	method := GeneratedEOCMethod 	newName: 		xMethod name
										Instance: 		xMethod isInstance 
										Abstract: 		xMethod isAbstract
										Constructor: 	xMethod isConstructor.

	xMethod parameters
		do: [:each | method
				addArgument: (GeneratedEOCVariable newName: each)].
			
	^ method! !

!DataForGenerator class methodsFor: 'private' stamp: 'volosmat 4/24/2014 11:19'!
searchClass: xName  
	[ ^ dataForGenerator classes detect: [ :each | each name = xName ] ]
		on: Error
		do: [ ^ nil ]! !

Object subclass: #Transform
	instanceVariableNames: 'element'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GMF-UMLModel'!

!Transform class methodsFor: 'instance creation' stamp: 'volosmat 4/10/2014 00:22'!
chooseTransformClass: xElement
	| package class |
	"from type of xElement detect which transform class to call"
	( xElement isKindOf: ElementClass)
		ifTrue: [ class := TransformElement element: xElement ];
		ifFalse: [ class := TransformAssociation element: xElement ].
	"find if exist specific transform class"	
	package := PackageInfo named: ( self package name ).
	( package classes
		anySatisfy: [:each | (each name asString) = ( 'Transform', xElement class asString ) ] )
		ifTrue: [ class := Compiler evaluate: 'Transform', xElement class asString,' new'. 
				 class element: xElement ].
		
	^ class transform! !

!Transform class methodsFor: 'private' stamp: 'volosmat 4/12/2014 20:32'!
element: xElement 
	^ super new initialize;
	   element: xElement;
	   yourself 
! !

!Transform class methodsFor: 'letters' stamp: 'volosmat 4/16/2014 23:24'!
replaceCapitalLetter: xWord
	| capital small tree | 
	
	tree := KeyedTree new.
	
	capital := ( $A to: $Z ).
	small := ( $a to: $z ).
	
	(1 to: capital size) do: [ :i | tree at: (capital at: i) put: (small at: i) ].
	
	[ ^ xWord copy replaceFrom: 1 to: 1 with: ( tree at: (xWord at: 1) ) asString startingAt: 1 ]
		on: Error
		do: [ ^ xWord ]! !

!Transform methodsFor: 'accessing' stamp: 'MatusVolosin 7/21/2013 15:42'!
element
	^ element! !

!Transform methodsFor: 'accessing' stamp: 'volosmat 4/9/2014 21:13'!
element: anObject
	element := anObject.
! !

!Transform methodsFor: 'transform' stamp: 'volosmat 4/9/2014 21:02'!
transform
	^ self subclassResponsibility! !

Transform subclass: #TransformAssociation
	instanceVariableNames: 'start end'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GMF-UMLModel'!

!TransformAssociation methodsFor: 'private' stamp: 'volosmat 4/24/2014 22:25'!
prepareNewComposition
	^ UMLComposition nameStart: 			( Transform replaceCapitalLetter: end name )
						nameEnd: 			( Transform replaceCapitalLetter: start name )
						start: 				start
						startMultiplicity: 	element startMultiplicity
						end: 				end
						endMultiplicity: 		element endMultiplicity! !

!TransformAssociation methodsFor: 'private' stamp: 'volosmat 4/24/2014 22:22'!
transform

	start 	:= TransformToUML searchTransformedElement: element start name.
	end		:= TransformToUML searchTransformedElement: element end name.
	
	element transformed: true.
	^ self prepareNewComposition
	! !

TransformAssociation subclass: #TransformDerivation
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GMF-UMLModel'!

!TransformDerivation methodsFor: 'private' stamp: 'volosmat 4/13/2014 19:25'!
transform 
	"characterization relation is use only for name of material relation"
	^ nil! !

TransformAssociation subclass: #TransformFormalAssociation
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GMF-UMLModel'!

!TransformFormalAssociation methodsFor: 'private' stamp: 'volosmat 4/13/2014 21:50'!
prepareNewComposition
	^ UMLComposition nameStart: 			element name
						nameEnd: 			element name
						start: 				start
						startMultiplicity: 	element startMultiplicity
						end: 				end
						endMultiplicity: 		element endMultiplicity! !

TransformAssociation subclass: #TransformMaterialAssociation
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GMF-UMLModel'!

!TransformMaterialAssociation methodsFor: 'private' stamp: 'volosmat 4/13/2014 19:26'!
transform
	"material association between two objects is related by Relator and mediation relation"
	^ nil! !

TransformAssociation subclass: #TransformMeronymic
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GMF-UMLModel'!

TransformMeronymic subclass: #TransformComponentOf
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GMF-UMLModel'!

!TransformComponentOf methodsFor: 'private' stamp: 'volosmat 4/23/2014 21:35'!
prepareNewComposition
	
	element isEssential | element isInseparable
		ifTrue: [ self createConstructor ].
		
	^ UMLComposition nameStart: 			( Transform replaceCapitalLetter: end name )
						nameEnd: 			( Transform replaceCapitalLetter: start name )
						start: 				start
						startMultiplicity: 	element startMultiplicity
						end: 				end
						endMultiplicity: 		element endMultiplicity
						essential:			element isEssential
						inseparable: 		element isInseparable! !

TransformMeronymic subclass: #TransformMemberOf
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GMF-UMLModel'!

!TransformMeronymic methodsFor: 'private' stamp: 'volosmat 4/23/2014 21:00'!
createConstructor
	| constructor constructorName ontoElement umlElement |
	element isEssential
		ifTrue: [ constructorName 	:= Transform replaceCapitalLetter: start name.
				 ontoElement		:= TransformToUML searchElementByName: end name. 
				 umlElement 		:= end].
	element isInseparable
		ifTrue: [ constructorName 	:= Transform replaceCapitalLetter: end name.
				 ontoElement		:= TransformToUML searchElementByName: start name.
				 umlElement 		:= start.  
				 umlElement attributes add: ( Attribute name: 	   	'composited' 
														dataType: 	'bool'
														multiplicity: '1'
														element:  	 ontoElement) ].
	
	[ constructor := ontoElement methods detect: [ :each | each isConstructor = true ] ]
		on: Error
		do: [ constructor := Method 	name: constructorName
										instance: false  
										constructor: true 
										element: ontoElement. 
			  umlElement defaultConstructor: false.				
			  constructor parameters add: constructorName.
			  umlElement methods add: constructor. 
			  ^ constructor ].
	"if we have more than 1 essential or inseparable part we add it as parameter of constructor"
	constructor parameters add: constructorName.
	
	! !

!TransformMeronymic methodsFor: 'private' stamp: 'volosmat 4/23/2014 21:35'!
prepareNewComposition
	
	element isEssential | element isInseparable
		ifTrue: [ self createConstructor ].
		
	^ UMLComposition nameStart: 			( Transform replaceCapitalLetter: end name )
						nameEnd: 			'members'
						start: 				start
						startMultiplicity: 	element startMultiplicity
						end: 				end
						endMultiplicity: 		element endMultiplicity
						essential:			element isEssential
						inseparable: 		element isInseparable! !

TransformMeronymic subclass: #TransformSubCollectionOf
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GMF-UMLModel'!

TransformMeronymic subclass: #TransformSubQuantityOf
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GMF-UMLModel'!

!TransformSubQuantityOf methodsFor: 'private' stamp: 'volosmat 4/24/2014 22:30'!
prepareNewComposition
	
	element isEssential | element isInseparable
		ifTrue: [ self createConstructor ].
		
	^ UMLComposition nameStart: 			( Transform replaceCapitalLetter: end name )
						nameEnd: 			( Transform replaceCapitalLetter: start name )
						start: 				start
						startMultiplicity: 	element startMultiplicity
						end: 				end
						endMultiplicity: 		element endMultiplicity
						essential:			true
						inseparable: 		false! !

Transform subclass: #TransformElement
	instanceVariableNames: 'transformedElement'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GMF-UMLModel'!

TransformElement subclass: #TransformAntiRigidSortal
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GMF-UMLModel'!

!TransformAntiRigidSortal methodsFor: 'private' stamp: 'volosmat 4/24/2014 15:38'!
prepareElementToTransform 
	"create new UML element"
	transformedElement := UMLElement name: element name.
	"phase and role always have a parent"
	self transformElementWithParent.
												! !

TransformAntiRigidSortal subclass: #TransformPhase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GMF-UMLModel'!

!TransformPhase methodsFor: 'private' stamp: 'volosmat 4/12/2014 18:46'!
transformElementWithParent 
	| ontoParents umlParent |
	
	"first find all parents with disjoint and complete inheritance"
	ontoParents := element parents 
						select: [ :each | each isDisjoint & each isComplete ].
		
	"now we can iterate over ontoParents"	
	ontoParents 
		do: [ :ontoParent |  
			"if parent is not transformed first i need transform it"
			( umlParent := TransformToUML searchTransformedElement: ontoParent parentClass name ) isNil 
				ifTrue: [ umlParent := Transform chooseTransformClass: ontoParent parentClass ].
			
			UMLComposition 	nameStart: 'phase'
								nameEnd: (Transform replaceCapitalLetter: (ontoParent parentClass name copy))
								start: umlParent
								startMultiplicity: '1'
								end: transformedElement
								endMultiplicity: '1'. 
		].
					
	! !

TransformAntiRigidSortal subclass: #TransformRole
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GMF-UMLModel'!

!TransformRole methodsFor: 'private' stamp: 'volosmat 4/12/2014 23:45'!
transformElementWithParent 
	| ontoParent umlParent |
	
	ontoParent := element parents detect: [ :each | each parentClass isKindOf: SortalClass ].
	
	"if parent is not transformed first i need transform it"
	( umlParent := TransformToUML searchTransformedElement: ontoParent parentClass name ) isNil 
		ifTrue: [ umlParent := Transform chooseTransformClass: ontoParent parentClass].
	
	UMLComposition 	nameStart: 			'roles' 
						nameEnd: 			( Transform replaceCapitalLetter: ontoParent parentClass name )  
						start: 				umlParent
						startMultiplicity: 	'0..*' 
						end: 				transformedElement 
						endMultiplicity: 		1! !

!TransformElement methodsFor: 'private' stamp: 'volosmat 4/13/2014 17:36'!
prepareElementToTransform

	(element parents anySatisfy: [ :each | each parentClass isKindOf: RigidSortalClass ])
		ifTrue: [ transformedElement := self transformElementWithParent  ];
		
		ifFalse: [ transformedElement := UMLElement 	name: 		element name 
														abstract: 	element isAbstract]
		
! !

!TransformElement methodsFor: 'private' stamp: 'volosmat 4/24/2014 18:41'!
transform
	"check parent collection"
	self prepareElementToTransform.
	
	"add attributes and methods to transformed elements"
	transformedElement notNil 
		ifTrue: [ transformedElement attributes: element attributes copy.
				 transformedElement methods:	  element methods copy ].
	
	"set flag in metamodel that this element was transformed"
	element transformed: true.
	
	^ transformedElement 
	
! !

!TransformElement methodsFor: 'private' stamp: 'volosmat 4/13/2014 13:29'!
transformElementWithParent
	"This method is for transfrom element with parent"
	| ontoParent umlParent |
	
	
	ontoParent	 := element parents detect: [ :each | each parentClass isKindOf: RigidSortalClass ].
	"if parent is not transformed first i need transform it"
	( umlParent := TransformToUML searchTransformedElement: ontoParent parentClass name ) isNil 
		ifTrue: [ umlParent := Transform chooseTransformClass: ontoParent parentClass].
	ontoParent isDisjoint
		ifFalse: [ ^ self transformNonDisjointInheritance: umlParent ];
		ifTrue: [  
				"and now create and return new uml element"
				^ UMLElement name: 		element name 
				     			     parent: 		umlParent
				     			     abstract: 	element isAbstract
				     			     disjoint: 	ontoParent isDisjoint
				     			     complete: 	ontoParent isComplete  ]
! !

!TransformElement methodsFor: 'private' stamp: 'volosmat 4/12/2014 22:42'!
transformNonDisjointInheritance: xUMLParent 
	| childs elementName compositeElements newElement |
	"Select all childs of UMLParent"
	childs := OrderedCollection new.
	TransformToUML dataToTransform
		do: [:each | each parents
				do: [:parent | parent parentClass name = xUMLParent name
							& (each isMemberOf: SubKind)
						ifTrue: [childs add: each]]].
	"Create all possible combinations of this childs"
	(1 to: childs size)
		do: [:i | childs
				combinations: i
				atATimeDo: [:combinations | 
					elementName := ''.
					compositeElements := OrderedCollection new.
					"Join all items from one combination to one string"
					combinations
						do: [:each | 
							elementName := elementName , each name.
							compositeElements add: each].
					newElement := UMLElement
								name: 		elementName
								parent: 	xUMLParent
								abstract: 	element isAbstract
								disjoint: 	false
								complete: 	false.
					"if newElement is original child we need copy attributes and methods and set flag isTransformed = true"
					i = 1
						ifTrue: [newElement attributes: (combinations at: 1) attributes copy.
							newElement methods: (combinations at: 1) methods copy.
							(combinations at: 1)
								transformed: true];
						
						ifFalse: [compositeElements
								do: [:each | UMLComposition
										nameStart: 			(Transform replaceCapitalLetter: each name)
										nameEnd: 			(Transform replaceCapitalLetter: newElement name)
										start: 				newElement
										startMultiplicity: 	1
										end: 				(TransformToUML searchTransformedElement: each name)
										endMultiplicity: 		1]]]].
					
	^ TransformToUML searchTransformedElement: element name! !

TransformElement subclass: #TransformMixinClass
	instanceVariableNames: 'childs'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GMF-UMLModel'!

TransformMixinClass subclass: #TransformCategory
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GMF-UMLModel'!

!TransformCategory methodsFor: 'private' stamp: 'volosmat 4/23/2014 21:25'!
prepareElementToTransform 
	"add all category subObjects to collection"
	childs := element subObjects.
	super prepareElementToTransform
	! !

TransformMixinClass subclass: #TransformMixin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GMF-UMLModel'!

!TransformMixin methodsFor: 'private' stamp: 'volosmat 4/13/2014 17:36'!
prepareElementToTransform 
	"add all mixin mixObjects to collection"
	childs := element mixObjects.
	super prepareElementToTransform! !

!TransformMixinClass methodsFor: 'private' stamp: 'volosmat 4/13/2014 17:36'!
prepareElementToTransform 
	| transformedChild |
	"create new UML element"
	transformedElement := UMLElement name: element name.
	
	childs do: [ :child |  
		( transformedChild := TransformToUML searchTransformedElement: child name ) isNil 
			ifTrue: [ transformedChild := Transform chooseTransformClass: child ].
			
		UMLComposition 	nameStart: 			( Transform replaceCapitalLetter: transformedChild name )
							nameEnd:  			( Transform replaceCapitalLetter: element name )
							start: 				transformedElement
							startMultiplicity: 	'0'
							end: 				transformedChild 
							endMultiplicity: 		'1'
		]! !

!TransformMixinClass methodsFor: 'private' stamp: 'volosmat 4/13/2014 15:30'!
transformElementWithParent 
	^ self error: 'Not Implemented for MixinClasses'! !

TransformMixinClass subclass: #TransformRoleMixin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GMF-UMLModel'!

!TransformRoleMixin methodsFor: 'private' stamp: 'volosmat 4/13/2014 17:36'!
prepareElementToTransform 
	"add all roles of RoleMixin to collection"
	childs := element roles.
	super prepareElementToTransform! !

TransformElement subclass: #TransformMomentClass
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GMF-UMLModel'!

TransformMomentClass subclass: #TransformQuality
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GMF-UMLModel'!

!TransformQuality methodsFor: 'private' stamp: 'volosmat 4/24/2014 18:40'!
createAttributes
	| ontoElement attribute umlElement multiplicity |
	
	element associations 
		do: [ :each | each start = element 
						ifTrue: [ ontoElement := each end.
								 multiplicity    := each endMultiplicity ];
						ifFalse: [ ontoElement := each start.
								  multiplicity    := each startMultiplicity ].
			attribute := Attribute 	name: each name
									dataType: nil 
									multiplicity: multiplicity
									element: ontoElement.
			( umlElement := TransformToUML searchTransformedElement: ontoElement name) notNil 
				ifTrue: [ umlElement attributes add: attribute ].
			each transformed: true
			]
									
	! !

!TransformQuality methodsFor: 'private' stamp: 'volosmat 4/24/2014 18:36'!
prepareElementToTransform
	
	element asAttribute
		ifFalse: [ transformedElement := UMLElement name: element name ];
		ifTrue: [ self createAttributes ]! !

Object subclass: #TransformToUML
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GMF-UMLModel'!

TransformToUML class
	instanceVariableNames: 'dataToTransform transformedElements'!

!TransformToUML commentStamp: 'volosmat 4/29/2014 10:19' prior: 0!
A TransformToUML is the main class of OntoUML >> UML transform.

Example:
metamodel := MetaModel new.
Kind name: 'TestKind' metaModel: metamodel.

TransformToUML metaModel: metamodel.

This message return all UML elements:
TransformToUML transformedElements.

If you can send data to GMF-Generator see class DataForGenerator.
!

TransformToUML class
	instanceVariableNames: 'dataToTransform transformedElements'!

!TransformToUML class methodsFor: 'adding' stamp: 'volosmat 4/24/2014 14:40'!
addTransformedElement: xElement
	transformedElements ifNil: [ transformedElements := OrderedCollection new ].
	transformedElements add: xElement! !

!TransformToUML class methodsFor: 'testing' stamp: 'volosmat 4/24/2014 15:30'!
clearTransformedElements
	transformedElements := nil! !

!TransformToUML class methodsFor: 'accessing' stamp: 'volosmat 4/12/2014 20:35'!
dataToTransform
	^ dataToTransform copy! !

!TransformToUML class methodsFor: 'initialize data' stamp: 'volosmat 4/23/2014 20:32'!
metaModel: xMetaModel

	dataToTransform := xMetaModel modelElements.
	self transformAll! !

!TransformToUML class methodsFor: 'private' stamp: 'volosmat 4/9/2014 15:49'!
readNextElement
	[ ^ dataToTransform detect: [ :each | each isTransformed not ] ]
		on: Error
		do: [ ^ nil ]! !

!TransformToUML class methodsFor: 'search' stamp: 'volosmat 4/15/2014 10:00'!
searchElementByName: xName
	[ ^ dataToTransform detect: [ :each | each name = xName] ]
		on: Error
		do: [ ^ nil ]! !

!TransformToUML class methodsFor: 'search' stamp: 'volosmat 4/9/2014 16:22'!
searchElementByType: xType
	[ ^ dataToTransform detect: [ :each | (each isMemberOf: xType) & (each isTransformed not )] ]
		on: Error
		do: [ ^ nil ]! !

!TransformToUML class methodsFor: 'search' stamp: 'volosmat 4/9/2014 17:48'!
searchTransformedElement: xName 
	[ ^ transformedElements detect: [ :each | each name = xName ] ]
		on: Error
		do: [ ^ nil ]! !

!TransformToUML class methodsFor: 'private' stamp: 'volosmat 4/24/2014 18:37'!
transformAll
	| element |
	"initialization collection of transformed elements"
	transformedElements := OrderedCollection new.
	"initialization of model data"
	dataToTransform 
		do: [ :elem |  elem transformed: false.
			elem associations 
				do: [ :ass | ass transformed: false] ].
	"first transform categories, then mixins and then kinds"
	self transformType: Category.
	self transformType: Mixin.
	self transformType: RoleMixin.
	self transformType: Kind.
	"after transform other elements"
	[ element := self readNextElement ] whileNotNil: [ 
		Transform chooseTransformClass: element
	].
	"transform all associations"
	dataToTransform 
		do: [ :elem |  elem associations 
			do: [ :ass | ass isTransformed
							ifFalse: [Transform chooseTransformClass: ass] ] ]! !

!TransformToUML class methodsFor: 'private' stamp: 'volosmat 4/13/2014 15:40'!
transformType: xType
	| element |
	
	[ element := self searchElementByType: xType ] whileNotNil: [ 
		Transform chooseTransformClass: element
	].! !

!TransformToUML class methodsFor: 'accessing' stamp: 'volosmat 4/24/2014 14:41'!
transformedElements
	^ (transformedElements copy) ifNil: [ transformedElements := OrderedCollection new ]! !

Object subclass: #UMLComposition
	instanceVariableNames: 'start end nameStart nameEnd startMultiplicity endMultiplicity essential inseparable'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GMF-UMLModel'!

!UMLComposition class methodsFor: 'instance creation' stamp: 'volosmat 4/24/2014 10:51'!
nameStart: xNameStart nameEnd: xNameEnd start: xStart startMultiplicity: xStartMulti end: xEnd endMultiplicity: xEndMulti
	^ super new initialize 
		 nameStart: 		xNameStart;
	    	 nameEnd: 			xNameEnd;
		 start: 				xStart;
		 end: 				xEnd;
		 startMultiplicity: 	xStartMulti;
		 endMultiplicity: 	xEndMulti;
		 yourself! !

!UMLComposition class methodsFor: 'instance creation' stamp: 'volosmat 4/16/2014 23:01'!
nameStart: xNameStart nameEnd: xNameEnd start: xStart startMultiplicity: xStartMulti end: xEnd endMultiplicity: xEndMulti essential: xEssential inseparable: xInseparable
	^ super new initialize 
		 nameStart: 		xNameStart;
	    	 nameEnd: 			xNameEnd;
		 start: 				xStart;
		 end: 				xEnd;
		 startMultiplicity: 	xStartMulti;
		 endMultiplicity: 	xEndMulti;
		 essential: 			xEssential;
		 inseparable: 		xInseparable;
		 yourself! !

!UMLComposition class methodsFor: 'instance creation' stamp: 'volosmat 4/24/2014 10:51'!
new
	^ self shouldNotImplement! !

!UMLComposition methodsFor: 'accessing' stamp: 'volosmat 5/9/2013 20:30'!
end
	^ end! !

!UMLComposition methodsFor: 'accessing' stamp: 'volosmat 4/10/2014 10:15'!
end: xEnd
	end := xEnd.
	xEnd compositions add: self.! !

!UMLComposition methodsFor: 'accessing' stamp: 'volosmat 4/12/2014 16:18'!
endMultiplicity
	^ endMultiplicity ifNil: [ endMultiplicity := '0' ]! !

!UMLComposition methodsFor: 'accessing' stamp: 'volosmat 5/9/2013 20:31'!
endMultiplicity: anObject
	endMultiplicity := anObject! !

!UMLComposition methodsFor: 'accessing' stamp: 'volosmat 4/15/2014 18:52'!
essential: xEssential
	essential := xEssential! !

!UMLComposition methodsFor: 'accessing' stamp: 'volosmat 4/16/2014 23:00'!
inseparable: xInseparable
	inseparable := xInseparable! !

!UMLComposition methodsFor: 'accessing' stamp: 'volosmat 4/15/2014 18:54'!
isEssential
	^ essential ifNil: [ essential := false ]! !

!UMLComposition methodsFor: 'accessing' stamp: 'volosmat 4/16/2014 23:00'!
isInseparable
	^ inseparable ifNil: [ inseparable := false ]! !

!UMLComposition methodsFor: 'accessing' stamp: 'volosmat 7/17/2013 12:25'!
nameEnd
	^ nameEnd! !

!UMLComposition methodsFor: 'accessing' stamp: 'volosmat 7/17/2013 12:26'!
nameEnd: anObject
	nameEnd := anObject! !

!UMLComposition methodsFor: 'accessing' stamp: 'volosmat 7/17/2013 12:25'!
nameStart
	^ nameStart! !

!UMLComposition methodsFor: 'accessing' stamp: 'volosmat 7/17/2013 12:26'!
nameStart: anObject
	nameStart := anObject! !

!UMLComposition methodsFor: 'accessing' stamp: 'volosmat 7/17/2013 12:26'!
start
	^start! !

!UMLComposition methodsFor: 'accessing' stamp: 'volosmat 4/10/2014 10:16'!
start: xStart
	start := xStart.
	xStart compositions add: self! !

!UMLComposition methodsFor: 'accessing' stamp: 'volosmat 4/12/2014 16:18'!
startMultiplicity
	^ startMultiplicity ifNil: [ startMultiplicity := '0' ]! !

!UMLComposition methodsFor: 'accessing' stamp: 'volosmat 5/9/2013 20:31'!
startMultiplicity: anObject
	startMultiplicity := anObject! !

Object subclass: #UMLElement
	instanceVariableNames: 'attributes methods compositions parent name abstract disjoint complete defaultConstructor'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GMF-UMLModel'!

!UMLElement class methodsFor: 'instance creation' stamp: 'volosmat 7/16/2013 15:24'!
name: xName

	^(super new initialize)
		name: xName;
		parent: nil;
		disjoint: nil;
		yourself! !

!UMLElement class methodsFor: 'instance creation' stamp: 'volosmat 4/9/2014 17:42'!
name: xName abstract: xAbstract

	^(super new initialize)
		name: 	   xName;
		abstract: xAbstract;
		yourself! !

!UMLElement class methodsFor: 'instance creation' stamp: 'volosmat 4/9/2014 17:42'!
name: xName parent: xParent abstract: xAbstract disjoint: xDisjoint complete: xComplete

	^(super new initialize)
		name: 		xName;
		parent: 	xParent;
		abstract: 	xAbstract;
		disjoint: 	xDisjoint;
		complete: 	xComplete;
		yourself! !

!UMLElement class methodsFor: 'instance creation' stamp: 'volosmat 4/24/2014 10:52'!
new
	^ self shouldNotImplement! !

!UMLElement methodsFor: 'accessing' stamp: 'volosmat 7/16/2013 14:35'!
abstract: anObject
	abstract := anObject! !

!UMLElement methodsFor: 'accessing' stamp: 'volosmat 4/9/2014 17:20'!
attributes
	^ attributes! !

!UMLElement methodsFor: 'accessing' stamp: 'volosmat 4/9/2014 17:20'!
attributes: anObject
	attributes := anObject! !

!UMLElement methodsFor: 'accessing' stamp: 'volosmat 4/9/2014 17:39'!
complete: xComplete
	complete := xComplete! !

!UMLElement methodsFor: 'accessing' stamp: 'Anonymous 5/8/2013 17:47'!
compositions
	^ compositions! !

!UMLElement methodsFor: 'accessing' stamp: 'Anonymous 5/8/2013 17:47'!
compositions: anObject
	compositions := anObject! !

!UMLElement methodsFor: 'accessing' stamp: 'volosmat 4/23/2014 19:51'!
defaultConstructor
	^ defaultConstructor ifNil: [ defaultConstructor := true ]! !

!UMLElement methodsFor: 'accessing' stamp: 'volosmat 4/23/2014 19:50'!
defaultConstructor: anObject
	defaultConstructor := anObject! !

!UMLElement methodsFor: 'accessing' stamp: 'volosmat 4/9/2014 16:31'!
disjoint: xDisjoint
	disjoint := xDisjoint! !

!UMLElement methodsFor: 'initialize-release' stamp: 'volosmat 4/24/2014 18:29'!
initialize

	attributes 		:= OrderedCollection new.
	methods 		:= OrderedCollection new.
	compositions 	:= OrderedCollection new.
	abstract 		:= false.
	disjoint 		:= nil.
	complete 		:= nil.
			
	^ self! !

!UMLElement methodsFor: 'accessing' stamp: 'volosmat 4/9/2014 16:29'!
isAbstract
	^ abstract! !

!UMLElement methodsFor: 'accessing' stamp: 'volosmat 4/9/2014 17:43'!
isComplete
	( parent isNil )
		ifTrue: [ ^ nil ];
		ifFalse: [ ^ complete ]! !

!UMLElement methodsFor: 'accessing' stamp: 'volosmat 4/9/2014 16:31'!
isDisjoint
	( parent isNil )
		ifTrue: [ ^ nil ];
		ifFalse: [ ^ disjoint ]! !

!UMLElement methodsFor: 'accessing' stamp: 'Anonymous 5/8/2013 17:48'!
methods
	^ methods! !

!UMLElement methodsFor: 'accessing' stamp: 'Anonymous 5/8/2013 17:48'!
methods: anObject
	methods := anObject! !

!UMLElement methodsFor: 'accessing' stamp: 'Anonymous 5/8/2013 17:48'!
name
	^ name! !

!UMLElement methodsFor: 'accessing' stamp: 'volosmat 4/12/2014 20:55'!
name: anObject
	name isNil
		ifTrue: [ TransformToUML addTransformedElement: self ].
		
	name := anObject.! !

!UMLElement methodsFor: 'accessing' stamp: 'Anonymous 5/8/2013 17:48'!
parent
	^ parent! !

!UMLElement methodsFor: 'accessing' stamp: 'volosmat 4/9/2014 17:40'!
parent: anObject
	parent 		:= anObject.
	disjoint 	:= true.
	complete 	:= true
! !

!UMLElement methodsFor: 'search' stamp: 'volosmat 4/24/2014 16:01'!
searchComposition: xName end: xEnd
	[ ^ compositions detect: [ :each | (each nameStart = xName) | (each nameEnd = xName) ] ]
		on: Error
		do: [ ^ nil ]! !
